;; Generated package description from webfeeder.el  -*- no-byte-compile: t -*-
(define-package "webfeeder" "1.1.1.0.20201123.160858" "Build RSS and Atom webfeeds from HTML files" '((emacs "25.1")) :keywords '("news" "hypermedia" "blog" "feed" "rss" "atom") :authors '(("Pierre Neidhardt" . "mail@ambrevar.xyz")) :maintainer '("Pierre Neidhardt" . "mail@ambrevar.xyz") :url "https://gitlab.com/Ambrevar/emacs-webfeeder")
